import json

import requests


class GPT4oMini(object):

    @classmethod
    def get_ai_mini_title(cls, title):
        """AI标题"""
        url = "http://aigc-api.cybertogether.net//aigc/dev/test/gpt"
        payload = json.dumps({
            "imageList": [],
            "model": "gpt-4o-mini-2024-07-18",
            "prompt": (
                "你是一名短视频标题优化专家，任务是为短视频生成吸引力高且符合规范的标题。请你根据提供的视频口播内容，定位对于中国60岁以上老年人的核心吸引点与传播点，并根据以下要求输出利于老年人转发的标题。"
                "生成标题要求"
                 "1. 标题开头包含醒目emoji🔴，结尾不需要emoji🔴，整体字符长度必须控制在10-25个字，只生成一个标题即可"
                 "2. 如果视频内容中包含具体的观点，标题则重点突出观点，并增加对观点的肯定或态度，示例：听完觉得太对了，太香了、老外至今难以相信。如果视频中不包含具体观点，可利用口播中最吸引人的内容，若有数字可突出数字，若有描述可突出描述。示例：这样做牛肉就像豆腐一样软，没牙也能吃；韩红慈善20年，累计捐款10个亿"
                 "3. 禁止编造任何信息，如视频中不包含养老金相关的内容，不能在生成的标题中出现养老金。"
                 "4. 标题结尾可以根据标题内容增加一些对观点的判断或情绪输出的内容，吸引人点击。请注意，结尾的内容要和前文由关联性，不能看起来毫无关联。示例：你们见过吗、你听对不对、请听、太神奇了、一字一句都是金、句句难以辩驳"
                 "5. 标题内不能使用强引导分享点击的词句，如：快来看看、大家都听一听、值得一看、都看看吧、你也来看看吧、大家注意、都听听等。"
                 "6. 标题内不能使用无实质信息和强烈诱导点击、紧急、夸张、震惊的描述，避免使用“震惊国人”、“速看”、“太震撼了”等类似描述。"
                 "7. 标题需要适应老年人的阅读习惯，尽量使用大白话，不要使用年轻一代的网络流行语，如：太燃了、佛系、躺平、内卷、炸裂等。"
                "输出要求："
                "请基于优秀标题要求，参考优秀标题示例，生成吸引用户注意的标题。"
                "优秀标题分类及示例"
                "1、使用疑问和互动，引发好奇心："
                "🔴街头采访趣事，朋友们你认为说的对不对 "
                "🔴原来这就是中国如此强大的原因！"
                "🔴穿什么裤子最显年轻？ "
                "🔴真实的台湾，原来是这个样子的！ "
                "🔴涨知识了，日本唯一不敢攻打的城市是这里"
                "2、关联个人利益和情感："
                "🔴如果微信倒闭了，存的钱怎么办？大家注意！ "
                "🔴不结婚不生孩子，老了之后会是什么下场？ "
                "🔴这个视频勾起多少人童年的回忆，你还记得吗 "
                "🔴这八大建议一经提出，老百姓手都拍红了 "
                "3、文化和社会热点："
                "🔴国庆为什么要放假，看完你就明白了！ "
                "🔴淄博再次因为他而火！到底好不好，你来说了算！ "
                "🔴1900架无人机表演，龙飞凤舞堪比春晚 "
                "4、对观点/话题的感叹/肯定："
                "🔴这就是澳门的黄金发财树!太美了 "
                "🔴天地之间有杆称，说的真好❗" 
                f"请分析该内容，视频脚本内容为：{title}，返回新的标题。"
            ),
            "responseFormat": {
                "type": "json_schema",
                "json_schema": {
                    "strict": True,
                    "name": "share_script_result",
                    "schema": {
                        "type": "object",
                        "properties": {
                            "新标题": {
                                "type": "string",
                                "description": "生成新的标题"
                            }
                        },
                        "required": ["新标题"],
                        "additionalProperties": False
                    }
                }
            }
        })
        headers = {'Content-Type': 'application/json'}
        response = requests.post(url, headers=headers, data=payload)
        response_data = response.json()

        data = json.loads(response_data.get('data', '{}'))
        new_title = data["新标题"]
        if new_title:
            return new_title
        else:
            return None

if __name__ == '__main__':
    text ='主席的思想要传承，这个视频展现了一代伟人的伟大精神，真是让人感慨万千，我们享受的幸福生活，离不开那些为我们打下基础的人，尤其是伟大的毛主席，我们应该时刻铭记历史，珍惜来之不易的生活，如果你也和我一样深感震撼，想要让更多的人了解这段历史，就赶紧把这个视频分享给你所有的朋友和群聊吧，让我们一起传递这份感动，让更多的人铭记这份伟大的精神，祖国万岁，感谢有你'
    GPT4oMini.get_ai_mini_title(text)